diff lisp/cedet/semantic/doc.el @ 104442:b22b44e953cb

cedet/semantic/chart.el: Don't require semantic/find. cedet/semantic/complete.el: Don't require semantic/find. cedet/semantic/decorate.el: Require semantic/tag-file. (semantic-set-tag-folded-isearch): Require semantic/find. cedet/semantic/dep.el: Change semantic--dependency-find-file-on-path into a macro, to avoid compiler warning. Defvar ede-minor-mode and ede-object. Declare ede-system-include-path. cedet/semantic/doc.el: Require semantic/tag-file and semantic/find. cedet/semantic/edit.el: Require semantic/find and semantic/format. cedet/semantic/find.el: Defvar semantic-case-fold. Require semantic. (semantic-find-tags-external-children-of-type): Require semantic/sort. (semantic-find-tags-by-scope-protection-default): Require semantic/tag-ls. cedet/semantic/format.el: Require semantic/tag-ls. eval-when-compile semantic/find. (semantic-format-tag-name): Move up to avoid compiler error. (semantic-format-tag-prototype): Move up to avoid compiler error. (semantic--format-tag-parent-tree): Require semantic/tag-file. (semantic-format-tag-short-doc-default): Require semantic/doc.
author Chong Yidong <cyd@stupidchicken.com>
date Mon, 31 Aug 2009 02:16:34 +0000
parents b66bb908c129
children 2bf481006ba4
line wrap: on
line diff
--- a/lisp/cedet/semantic/doc.el	Mon Aug 31 00:45:41 2009 +0000
+++ b/lisp/cedet/semantic/doc.el	Mon Aug 31 02:16:34 2009 +0000
@@ -1,4 +1,4 @@
 ;;; doc.el --- Routines for documentation strings
 
 ;;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2005, 2008, 2009
 ;;; Free Software Foundation, Inc.
@@ -30,6 +30,8 @@
 ;; the symbol on the same line.
 
 (require 'semantic/tag)
+(require 'semantic/tag-file)
+(require 'semantic/find)
 
 ;;; Code:
 
@@ -125,4 +127,4 @@
 
 (provide 'semantic/doc)
 
-;;; semantic-doc.el ends here
+;;; semantic/doc.el ends here
@@ -1,4 +1,4 @@
-;;; doc.el --- Routines for documentation strings
+;;; semantic/doc.el --- Routines for documentation strings
 
 ;;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2005, 2008, 2009